@@ -1,5 +1,3 @@
-# -*- Mode: cperl; mode: folding; -*-
-
 package Goo::DatabaseObject;
 
 ###############################################################################
@@ -147,7 +145,7 @@ __END__
 
 =head1 NAME
 
-Goo::DatabaseObject - Bridge the relational and OO world!
+Goo::DatabaseObject - Bridge between relational and OO model
 
 =head1 SYNOPSIS
 
@@ -155,15 +153,13 @@ use Goo::DatabaseObject;
 
 =head1 DESCRIPTION
 
-
-
 =head1 METHODS
 
 =over
 
 =item new
 
-construct a goo_database_object object
+constructor
 
 =item delete
 
@@ -171,14 +167,13 @@ delete the current object in the database
 
 =item replace
 
-replace the entire row in the database with the 'state' of the
-
+replace the entire row in the database with the current 'state' of the object
 
 =back
 
 =head1 AUTHOR
 
-Nigel Hamilton <nigel@turbo10.com>
+Nigel Hamilton <nigel@trexy.com>
 
 =head1 SEE ALSO
 
