@@ -43,7 +43,7 @@ __END__
 
 =head1 NAME
 
-Goo::Header - Show a consistent style of text header for the GOO
+Goo::Header - Show a consistent style of text header for The Goo
 
 =head1 SYNOPSIS
 
@@ -59,14 +59,13 @@ use Goo::Header;
 
 =item show
 
-show a  the header in detail
-
+show a consistent header at the top of the screen
 
 =back
 
 =head1 AUTHOR
 
-Nigel Hamilton <nigel@turbo10.com>
+Nigel Hamilton <nigel@trexy.com>
 
 =head1 SEE ALSO
 
